

# Toolcraft

## Installation Instructions


`uv` is a fast Python package installer and resolver. For more information, visit the [official documentation](https://docs.astral.sh/uv/getting-started/installation/).

### Windows

**Option 1: PowerShell Installation**
```powershell
powershell -ExecutionPolicy ByPass -c "irm https://astral.sh/uv/install.ps1 | iex"
```

After installation, run:
```powershell
uvx toolcraft
```

**Option 2: Using Winget**
```bat
winget install --id=astral-sh.uv -e
```

After installation, run:
```powershell
uvx toolcraft
```

### Linux / macOS

```bash
curl -LsSf https://astral.sh/uv/install.sh | sh
```

After installation, run:
```bash
uvx toolcraft
```
